@@ -9,7 +9,7 @@ from utils.config import get_config
 
 
 def author_scholar_docs(author_id, output_format='dictionary', pretty_print=None, xml_library='dicttoxml',
-                        max_workers=None):
+                        min_year=None, max_year=None, max_workers=None):
     domain = get_config()['domain']
     url = f'{domain}/authors/detail?id={author_id}&view=documentsgs'
     html = get(url)
@@ -22,6 +22,12 @@ def author_scholar_docs(author_id, output_format='dictionary', pretty_print=None
         for page in range(2, n_page + 1):
             executor.submit(worker, author_id, page, worker_result)
 
+    if min_year is not None:
+        worker_result = [doc for doc in worker_result if is_integer(str(doc['year'])) and doc['year'] >= min_year]
+
+    if max_year is not None:
+        worker_result = [doc for doc in worker_result if is_integer(str(doc['year'])) and doc['year'] <= max_year]
+
     return utils.format_output(worker_result, output_format, pretty_print, xml_library)
 
 
